Index: orxonox/trunk/src/orxonox.h
===================================================================
--- orxonox/trunk/src/orxonox.h	(revision 3448)
+++ orxonox/trunk/src/orxonox.h	(revision 3449)
@@ -26,15 +26,15 @@
   ~Orxonox ();
   
-  char configfilename[256];
-  World* world;
-  DataTank* resources;
-  CommandNode* localinput;
-  Camera* localcamera;
-  SDL_Surface* screen;
-  GameLoader* gameLoader;
+  char configfilename[256];   //!< Filename of the configuration-file.
+  World* world;               //!< Reference to the current running world.
+  DataTank* resources;        //!< DataContainer
+  CommandNode* localinput;    //!< Command Handler
+  Camera* localcamera;        //!< The current Camera
+  SDL_Surface* screen;        //!< The current Screen
+  GameLoader* gameLoader;     //!< The gameLoader
   
-  bool bQuitOrxonox;
-  bool pause;
-  Uint32 lastframe;
+  bool bQuitOrxonox;          //!< If Orxonox should Quit
+  bool pause;                 //!< Pause mode
+  Uint32 lastframe;           //!< Time of the last Frame
   
   void getConfigFile (int argc, char** argv);
Index: orxonox/trunk/src/vector.cc
===================================================================
--- orxonox/trunk/src/vector.cc	(revision 3448)
+++ orxonox/trunk/src/vector.cc	(revision 3449)
@@ -151,5 +151,5 @@
 
 /**
-   \bref returns the voctor normalized to length 1.0
+   \brief returns the voctor normalized to length 1.0
 */
 
@@ -170,5 +170,8 @@
 }
 
-
+/**
+   \brief scales this Vector with Vector v.
+   \param v the vector to scale this vector with
+*/
 void Vector::scale(const Vector& v)
 {
@@ -189,5 +192,7 @@
 
 
-
+/**
+   \brief Vector is looking in the positive direction on all axes after this
+*/
 Vector Vector::abs() 
 {
@@ -473,5 +478,11 @@
 }
 
-
+/**
+   \brief performs a smooth move.
+   \param from from where
+   \param to to where
+   \param t the time this transformation should take
+   \param res The approximation-density
+*/
 void Quaternion::quatSlerp(const Quaternion* from, const Quaternion* to, float t, Quaternion* res)
 {
@@ -802,5 +813,5 @@
 /**
    \brief create a plane from anchor point and normal
-   \param n: normal vector
+   \param norm: normal vector
    \param p: anchor point
 */
Index: orxonox/trunk/src/vector.h
===================================================================
--- orxonox/trunk/src/vector.h	(revision 3448)
+++ orxonox/trunk/src/vector.h	(revision 3449)
@@ -10,4 +10,5 @@
 
 #include <math.h>
+//! PI the circle-constant
 #define PI 3.14159265359f
 
@@ -20,5 +21,7 @@
   public:
  
-  float x, y, z;
+  float x; //!< The x Coordinate of the Vector.
+  float y; //!< The y Coordinate of the Vector.
+  float z; //!< The z Coordinate of the Vector.
 
   Vector (float x, float y, float z) : x(x), y(y), z(z) {}  //!< assignment constructor
@@ -51,5 +54,5 @@
  public:
 	Vector v;	//!< Imaginary Vector
-	float w; //!< Real part of the number
+	float w;        //!< Real part of the number
 
  	Quaternion ();
@@ -72,5 +75,5 @@
 
  private:
-	float DELTA;
+	float DELTA;      //!< resolution of calculation
 
 };
Index: orxonox/trunk/src/world.cc
===================================================================
--- orxonox/trunk/src/world.cc	(revision 3448)
+++ orxonox/trunk/src/world.cc	(revision 3449)
@@ -46,4 +46,8 @@
 }
 
+/**
+   \brief creates a new World...
+   \param worldID with this ID
+*/
 World::World (int worldID)
 {
@@ -96,5 +100,7 @@
   {60.0, -10.0, 5.0}, {80.0, 10.0, 5.0}};
 
-
+/**
+   \brief initializes a new World
+*/
 ErrorMessage World::init()
 {
@@ -114,5 +120,7 @@
 
 
-
+/**
+   \brief starts the World
+*/
 ErrorMessage World::start()
 {
@@ -123,4 +131,9 @@
 }
 
+/**
+   \brief stops the world.
+
+   This happens, when the player decides to end the Level.
+*/
 ErrorMessage World::stop()
 {
@@ -129,4 +142,7 @@
 }
 
+/**
+   \brief pauses the Game
+*/
 ErrorMessage World::pause()
 {
@@ -134,5 +150,7 @@
 }
 
-
+/**
+   \brief ends the pause Phase
+*/
 ErrorMessage World::resume()
 {
@@ -140,5 +158,7 @@
 }
 
-
+/**
+   \brief destroys the World
+*/
 void World::destroy()
 {
@@ -146,5 +166,7 @@
 }
 
-
+/**
+   \brief shows the loading screen
+*/
 void World::displayLoadScreen ()
 {
@@ -160,5 +182,9 @@
 }
 
-
+/**
+   \brief removes the loadscreen, and changes over to the game
+
+   \todo take out the delay
+*/
 void World::releaseLoadScreen ()
 {
@@ -169,5 +195,7 @@
 }
 
-
+/**
+   \brief loads the World by initializing all resources, and set their default values.
+*/
 void World::load()
 {
@@ -334,14 +362,4 @@
 	    this->nullParent->setName ("NullParent");
 
-	    // create some path nodes
-	    this->pathnodes = new Vector[6];
-	    this->pathnodes[0] = Vector(0, 0, 0);
-	    this->pathnodes[1] = Vector(20, 10, 10);
-	    this->pathnodes[2] = Vector(40, 0, 10);
-	    this->pathnodes[3] = Vector(60, 10, 0);
-	    this->pathnodes[4] = Vector(80, 20, 10);
-	    this->pathnodes[5] = Vector(30, 50, 0);
-	    
-
 
 
@@ -795,5 +813,5 @@
 
 
-/*
+/**
   \brief main loop of the world: executing all world relevant function
 
@@ -950,5 +968,6 @@
    \brief add and spawn a new entity to this world
    \param entity to be added
-   \param location where to add
+   \param absCoor At what coordinates to add this entity.
+   \param absDir In which direction should it look.
 */
 void World::spawn(WorldEntity* entity, Vector* absCoor, Quaternion* absDir)
@@ -967,5 +986,5 @@
 
 
-/*
+/**
   \brief commands that the world must catch
   \returns false if not used by the world
@@ -978,5 +997,8 @@
 
 
-
+/**
+   \brief swaps two values
+   \todo make this a global function, and take it out of world
+*/
 void World::swap (unsigned char &a, unsigned char &b)
 {
Index: orxonox/trunk/src/world.h
===================================================================
--- orxonox/trunk/src/world.h	(revision 3448)
+++ orxonox/trunk/src/world.h	(revision 3449)
@@ -19,5 +19,9 @@
 class Light;
 
-//! The game environment
+//! The game world
+/**
+   this class initializes everything that should be displayed inside of the current level.
+   it is the main driving factor during gameplay.
+*/
 class World : public StoryEntity {
 
@@ -55,31 +59,28 @@
   void spawn (WorldEntity* entity, Vector* absCoor, Quaternion* absDir);
 
-  tList<WorldEntity>* entities;
+  tList<WorldEntity>* entities;//!< A template List of all entities. Every moving thing should be included here, and world automatically updates them.
   
   // base level data
-  TrackManager* trackManager;
-  Vector* pathnodes;
-  Camera* localCamera;  
+  TrackManager* trackManager;  //!< The reference of the TrackManager that handles the course through the Level.
+  Camera* localCamera;         //!< The current Camera
 
 
-  UPointCurve* testCurve;
  private:
-  Uint32 lastFrame; //!> last time of frame
-  bool bQuitOrxonox; //!> quit this application
-  bool bQuitCurrentGame; //!> quit only the current game and return to menu
-  bool bPause;
+  Uint32 lastFrame;             //!< last time of frame
+  bool bQuitOrxonox;            //!< quit this application
+  bool bQuitCurrentGame;        //!< quit only the current game and return to menu
+  bool bPause;                  //!< pause mode
 
-  GLMenuImageScreen* glmis;
+  GLMenuImageScreen* glmis;     //!< The Level-Loader Display
 
-  char* worldName;
-  int debugWorldNr;
-  GLuint objectList;
-  SDL_Surface *loadImage;
-  Skysphere* skySphere;
-  Light* light;
+  char* worldName;              //!< The name of this World
+  int debugWorldNr;             //!< The Debug Nr. needed, if something goes wrong
+  GLuint objectList;            //!< temporary: \todo this will be ereased soon
+  Skysphere* skySphere;         //!< The Environmental Heaven of orxonox \todo insert this to environment insted
+  Light* light;                 //!< The Lights of the Level
 
-  WorldEntity* localPlayer;
+  WorldEntity* localPlayer;     //!< The Player, you fly through the level.
  
-  PNode* nullParent;
+  PNode* nullParent;            //!< The zero-point, that everything has as its parent.
  
   void mainLoop ();
Index: orxonox/trunk/src/world_entity.cc
===================================================================
--- orxonox/trunk/src/world_entity.cc	(revision 3448)
+++ orxonox/trunk/src/world_entity.cc	(revision 3449)
@@ -118,5 +118,8 @@
 }
 
-
+/**
+   \brief sets the drawable state of this entity.
+   \param bDraw TRUE if draweable, FALSE otherwise
+*/
 void WorldEntity::setDrawable (bool bDraw)
 {
Index: orxonox/trunk/src/world_entity.h
===================================================================
--- orxonox/trunk/src/world_entity.h	(revision 3448)
+++ orxonox/trunk/src/world_entity.h	(revision 3449)
@@ -22,5 +22,5 @@
   virtual ~WorldEntity ();
 
-  OBJModel* model;
+  OBJModel* model;                  //!< The model that should be loaded for this entity.
   
   void setCollision (CollisionCluster* newhull);
@@ -45,9 +45,9 @@
   
  private:
-  const bool bFree;	
-  bool bCollide;
-  bool bDraw;
+  const bool bFree;	              //!< If the entity is free.
+  bool bCollide;                      //!< If it should be considered for the collisiontest.
+  bool bDraw;                         //!< If it should be visible.
 
-  CollisionCluster* collisioncluster;
+  CollisionCluster* collisioncluster; //!< The collision-Cluster of this entity.
 };
 

Index: orxonox/trunk/src/orxonox.cc
===================================================================
--- orxonox/trunk/src/orxonox.cc	(revision 3448)
+++ orxonox/trunk/src/orxonox.cc	(revision 3449)
@@ -56,7 +56,10 @@
 
 
 /* this is a singleton class to prevent duplicates */
 Orxonox* Orxonox::singletonRef = 0;
 
+/**
+   \returns reference or new Object of Orxonox if not existent.
+*/
 Orxonox* Orxonox::getInstance (void)
 {
@@ -322,5 +325,7 @@
 }
 
-
+/**
+   \return The reference of the SDL-screen of orxonox
+*/
 SDL_Surface* Orxonox::getScreen ()
 {
@@ -328,5 +333,9 @@
 }
 
-
+/**
+   \brief main function
+
+   here the journey begins
+*/
 int main(int argc, char** argv) 
 {  
@@ -56,7 +56,10 @@
 
 
-/* this is a singleton class to prevent duplicates */
+/** \brief this is a singleton class to prevent duplicates */
 Orxonox* Orxonox::singletonRef = 0;
 